@@ -1,23 +1,6 @@
 package Date::Holidays::GB::NIR;
 
-our $VERSION = '0.006';
-
-=head1 NAME
-
-Date::Holidays::GB::NIR - Date::Holidays class for GB-NIR (Northern Ireland)
-
-=head1 SYNOPSIS
-
-    use Date::Holidays::GB::NIR qw/ holidays is_holiday /;
-
-    # All holidays for Northern Ireland
-    my $holidays = holidays( year => 2013 );
-
-    if (is_holiday( year => 2013, month => 12, day => 25, ) {
-            print "No work today!";
-        }
-
-=cut
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 use warnings;
@@ -44,3 +27,22 @@ sub is_holiday {
 
 1;
 
+__END__
+
+=head1 NAME
+
+Date::Holidays::GB::NIR - Date::Holidays class for GB-NIR (Northern Ireland)
+
+=head1 SYNOPSIS
+
+    use Date::Holidays::GB::NIR qw/ holidays is_holiday /;
+
+    # All holidays for Northern Ireland
+    my $holidays = holidays( year => 2013 );
+
+    if ( is_holiday( year => 2013, month => 12, day => 25 ) ) {
+        print "No work today!";
+    }
+
+=cut
+
